@@ -10,6 +10,9 @@ using namespace std;
 class AppError
 {
 public:
+  AppError() { }
+  virtual ~AppError() { }
+
 	virtual string msg() const = 0;
 };
 
