@@ -1,6 +1,8 @@
 #include <stdio.h>
 #include <iostream>
 #include <unistd.h>
+#include <assert.h>
+
 #include "IPv4Address.h"
 #include "util.h"
 
@@ -9,7 +11,7 @@ char * IPv4Address::ptr() const
 {
 	static char ascii[16]; // 12 for octets, 3 dots, 1 null
 
-	unsigned int iaddr = ntohl(a.s_addr);
+	unsigned int iaddr = ntohl(m_addr.s_addr);
 	int oc1 = (iaddr & 0xFF000000)/16777216;
 	int oc2 = (iaddr & 0x00FF0000)/65536;
 	int oc3 = (iaddr & 0x0000FF00)/256;
@@ -20,25 +22,24 @@ char * IPv4Address::ptr() const
 	return ascii;	
 }
 
-bool IPv4Address::operator==( const IPv4Address & ipv4a ) const
+bool IPv4Address::operator==( const IPAddress & addr ) const
 {
-	if( ipv4a.a.s_addr == a.s_addr ) 
-		return true;
-	else
+	if ( addr.GetType() != GetType())
 		return false;
+
+	const IPv4Address *ipv4_addr = dynamic_cast<const IPv4Address*>(&addr);
+	assert( ipv4_addr != NULL);
+
+	return ipv4_addr->m_addr.s_addr == m_addr.s_addr;
 }
 
-ostream &operator<<( ostream &out, const IPv4Address &ipv4a )
+uint32_t IPv4Address::hash() const
 {
-	unsigned int iaddr = ntohl(ipv4a.a.s_addr);
-	int oc1 = (iaddr & 0xFF000000)/16777216;
-	int oc2 = (iaddr & 0x00FF0000)/65536;
-	int oc3 = (iaddr & 0x0000FF00)/256;
-	int oc4 = (iaddr & 0x000000FF);
-	out << oc1 << "." << oc2 << "." << oc3 << "." << oc4;
+	return m_addr.s_addr;
 }
 
-struct in_addr IPv4Address::toStruct() const
+IPAddress* IPv4Address::Clone() const
 {
-	return a;
+	return new IPv4Address(m_addr);
 }
+
