@@ -5,7 +5,7 @@
 
 using namespace std;
 
-PcapError::PcapError( char *func, char *errbuf )
+PcapError::PcapError( const char *func, char *errbuf )
 {
 	f=func;
 	e=errbuf;
