@@ -27,6 +27,8 @@
 #include <unistd.h> // needed on BSD
 #include <netinet/in.h>
 #include <netinet/tcp.h>
+#include <net/ethernet.h>
+#include "config.h"
 
 #ifndef BYTE_ORDER
 #ifdef WORDS_BIGENDIAN
@@ -36,18 +38,25 @@
 #endif // ifdef WORDS_BIGENDIAN
 #endif // ifndef BYTE_ORDER
             
-// network layer protocols
-// in the future, when tcptrack handles ipv6, there will be 
-// a NLP_IPV6.
-#define NLP_IPV4 1
-
 #define IP_HEADER_LEN 20
+#define IP6_HEADER_LEN 40
 #define TCP_HEADER_LEN 20
 #define ENET_HEADER_LEN 14
 #define SLL_HEADER_LEN 16
 #define VLAN_HEADER_LEN 4
 
+#ifndef ETHER_ADDR_LEN
 #define ETHER_ADDR_LEN 6
+#endif
+
+#ifndef ETHERTYPE_VLAN
+#define ETHERTYPE_VLAN 0x8100
+#endif
+
+#ifndef ETHERTYPE_IPV6
+#define ETHERTYPE_IPV6 0x86dd
+#endif
+
 /* Ethernet header */
 struct sniff_ethernet {
     u_char ether_dhost[ETHER_ADDR_LEN]; /* Destination host address */
@@ -78,6 +87,17 @@ struct sniff_ip {
     struct in_addr ip_src,ip_dst; /* source and dest address */
 };
 
+struct sniff_ip6 {
+  uint32_t ip_v6:4; /* version */
+  uint32_t ip_class:8; /* traffic class */
+  uint32_t ip_flow:20; /* flow label */
+  uint32_t ip_len:16;  /* payload length */
+  uint32_t ip_next:8;  /* next header */
+  uint32_t ip_hop:8;   /* hop limit */
+  struct in6_addr ip_src; /* src address */
+  struct in6_addr ip_dst; /* dst address */
+};
+
 /* TCP header */
 struct sniff_tcp {
     u_short th_sport; /* source port */
